<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Moral
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function franchise_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// When  color scheme is light or dark.
	$color_scheme = get_theme_mod( 'franchise_color_scheme', 'lite' );
	$classes[] = esc_attr( $color_scheme ) . '-version';
	
	$classes[] = ( is_active_sidebar( 'sidebar-1' ) ) ? 'right-sidebar' : 'no-sidebar' ;

	$classes[] = 'classic-menu';
	
	return $classes;
}
add_filter( 'body_class', 'franchise_body_classes' );

function franchise_post_classes( $classes ) {
	if ( franchise_is_page_displays_posts() ) {
		// Search 'has-post-thumbnail' returned by default and remove it.
		$key = array_search( 'has-post-thumbnail', $classes );
		unset( $classes[ $key ] );
		
		if( has_post_thumbnail() ) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}
	}

	return $classes;
}
add_filter( 'post_class', 'franchise_post_classes' );

/**
 * Excerpt length
 * 
 * @since Moral 1.0.0
 * @return Excerpt length
 */
function franchise_excerpt_length( $length ){
	if ( is_admin() ) {
		return $length;
	}

	$length = get_theme_mod( 'franchise_archive_excerpt_length', 40 );
	return $length;
}
add_filter( 'excerpt_length', 'franchise_excerpt_length', 999 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function franchise_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'franchise_pingback_header' );

/**
 * Get an array of post id and title.
 * 
 */
function franchise_get_post_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'franchise' ) );
	$args = array( 'numberposts' => -1, );
	$posts = get_posts( $args );

	foreach ( $posts as $post ) {
		$id = $post->ID;
		$title = $post->post_title;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Checks to see if we're on the homepage or not.
 */
function franchise_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function franchise_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Posts page".
 */
function franchise_is_frontpage_blog() {
	return ( is_home() && ! is_front_page() );
}

/**
 * Checks to see if the current page displays any kind of post listing.
 */
function franchise_is_page_displays_posts() {
	return ( franchise_is_frontpage_blog() || is_search() || is_archive() || franchise_is_latest_posts() );
}

/**
 * Pagination in archive/blog/search pages.
 */
function franchise_posts_pagination() { 
	$archive_pagination = get_theme_mod( 'franchise_archive_pagination_type', 'numeric' );
	if ( 'disable' === $archive_pagination ) {
		return;
	}
	if ( 'numeric' === $archive_pagination ) {
		the_posts_pagination( array(
            'prev_text'          => franchise_get_svg( array( 'icon' => 'left-arrow' ) ) . esc_html__( 'Previous', 'franchise' ),
            'next_text'          => esc_html__( 'Next', 'franchise' ) . franchise_get_svg( array( 'icon' => 'left-arrow' ) ),
        ) );
	} elseif ( 'older_newer' === $archive_pagination ) {
        the_posts_navigation( array(
            'prev_text'          => franchise_get_svg( array( 'icon' => 'left-arrow' ) ) . '<span>'. esc_html__( 'Older', 'franchise' ) .'</span>',
            'next_text'          => '<span>'. esc_html__( 'Newer', 'franchise' ) .'</span>' . franchise_get_svg( array( 'icon' => 'left-arrow' ) ),
        )  );
	}
}

// Add auto p to the palces where get_the_excerpt is being called.
add_filter( 'get_the_excerpt', 'wpautop' );